package cn.com.infosec.asn1.cms;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;

public class KEKRecipientInfo extends ASN1Encodable {
   private DERInteger version;
   private KEKIdentifier kekid;
   private AlgorithmIdentifier keyEncryptionAlgorithm;
   private ASN1OctetString encryptedKey;

   public KEKRecipientInfo(KEKIdentifier kekid, AlgorithmIdentifier keyEncryptionAlgorithm, ASN1OctetString encryptedKey) {
      KEKRecipientInfo var10000 = this;
      KEKRecipientInfo var10001 = this;
      KEKRecipientInfo var10002 = this;
      KEKRecipientInfo var10003 = this;
      super();
      DERInteger var4;
      var4 = new DERInteger.<init>(4);
      var10003.version = var4;
      var10002.kekid = kekid;
      var10001.keyEncryptionAlgorithm = keyEncryptionAlgorithm;
      var10000.encryptedKey = encryptedKey;
   }

   public KEKRecipientInfo(ASN1Sequence seq) {
      this.version = (DERInteger)seq.getObjectAt(0);
      this.kekid = KEKIdentifier.getInstance(seq.getObjectAt(1));
      this.keyEncryptionAlgorithm = AlgorithmIdentifier.getInstance(seq.getObjectAt(2));
      this.encryptedKey = (ASN1OctetString)seq.getObjectAt(3);
   }

   public static KEKRecipientInfo getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static KEKRecipientInfo getInstance(Object obj) {
      if (obj != null && !(obj instanceof KEKRecipientInfo)) {
         if (obj instanceof ASN1Sequence) {
            return new KEKRecipientInfo((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("Invalid KEKRecipientInfo: " + obj.getClass().getName());
         }
      } else {
         return (KEKRecipientInfo)obj;
      }
   }

   public DERInteger getVersion() {
      return this.version;
   }

   public KEKIdentifier getKekid() {
      return this.kekid;
   }

   public AlgorithmIdentifier getKeyEncryptionAlgorithm() {
      return this.keyEncryptionAlgorithm;
   }

   public ASN1OctetString getEncryptedKey() {
      return this.encryptedKey;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10000 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.version);
      var1.add(this.kekid);
      var1.add(this.keyEncryptionAlgorithm);
      var10000.add(this.encryptedKey);
      return new DERSequence(var1);
   }
}
